@@ -33,8 +33,8 @@ TableRowData::~TableRowData()
 }
 
 
-PictureData::PictureData( SharedPtr<const Word97::PICF> sharedPicf ) :
-    picf( sharedPicf )
+PictureData::PictureData( U32 fc, SharedPtr<const Word97::PICF> sharedPicf ) :
+    fcPic( fc ), picf( sharedPicf )
 {
 }
 
