@@ -588,6 +588,7 @@ int main(int, char**) {
         std::cout << "Passed." << std::endl;
     else
         std::cout << "Failed." << std::endl;
+    metafilepict1.dump();
     // End of writing test for METAFILEPICT
 
     // Begin of writing test for NUMRM
@@ -702,6 +703,7 @@ int main(int, char**) {
         std::cout << "Passed." << std::endl;
     else
         std::cout << "Failed." << std::endl;
+    picf1.dump();
     // End of writing test for PICF
 
     // Begin of writing test for RR
